# pythonpro
Modulo para exemplificar a construção de projetos no curso PyTools  
Nesse curso é ensinado como contribuir com projetos de código aberto
[![Build Status](https://travis-ci.com/juliomsouza/pythonpro.svg?branch=main)](https://travis-ci.com/juliomsouza/pythonpro)

[![Updates](https://pyup.io/repos/github/juliomsouza/pythonpro/shield.svg)](https://pyup.io/repos/github/juliomsouza/pythonpro/)

[![Python 3](https://pyup.io/repos/github/juliomsouza/pythonpro/python-3-shield.svg)](https://pyup.io/repos/github/juliomsouza/pythonpro/)

Suportado a versão 3 de Python
Para instalar:
'''console
python3 -m venv .venv3
source .venv3/bin/activate
pip install -r requirements-dev.txt
'''
Para conferir o código:
'''console
flake8
'''

